Module events

Module events 

Structs

AddressMapping
Debug information for a specific address within a module
BacktraceDisplay
BacktraceDisplayFrame
ComplexVariableDisplay
EventRegistry
Registry for event communication between TUI and runtime
ExprErrorDisplay
ModuleDebugInfo
Debug information for a module (binary) containing one or more addresses
ModuleLoadingStats
Statistics for a loaded module
PathSubstitution
Path substitution rule (shared definition)
RuntimeChannels
Channels used by the runtime to receive commands and send events
ScriptCompilationDetails
Detailed compilation result for a script with multiple targets
ScriptExecutionResult
Result of executing a single script target (PC/function)
SectionInfo
Section information for executable files
SharedLibraryInfo
Shared library information (similar to GDB’s “info share” output)
SourceCodeInfo
Source code information for display in TUI
SourceFileGroup
Group of source files for a specific module
SourceFileInfo
Source file information
SourcePathInfo
Source path information for display (shared between UI and runtime)
TargetDebugInfo
Debug information for a target (function or source location)
TraceDefinition
Definition of a trace to be loaded
TraceDetailInfo
Detailed information for a specific trace
TraceLoadDetail
Result of loading a single trace
TraceSummaryInfo
Summary information for all traces
UiTraceEvent
Runtime trace event after conversion into display items.
VariableDebugInfo
Variable debug information
VariableDisplay

Enums

ExecutionStatus
Execution status for individual script targets
LoadStatus
Status of loading a trace
RuntimeCommand
Commands that TUI can send to runtime
RuntimeStatus
TargetType
Type of target being inspected
TraceDisplayItem
TraceStatus
Trace status enumeration for shared use between UI and runtime
TuiEvent
TUI events that can be handled by the application

Constants

DEFAULT_TRACE_CHANNEL_CAPACITY
Default queue size for runtime->UI trace events.